package com.huashe.park.core.service;

import java.util.HashMap;
import java.util.List;

import com.huashe.park.domain.dto.cons.ConsPileHoleInfoVO;
import com.huashe.park.domain.dto.cons.ConstUnitNode;
import com.huashe.park.domain.dto.cons.MachineBiz;
import com.huashe.park.domain.entity.PileMachineInfo;

/**
 * 施工桩机信息Service接口
 * 
 * @author ruoyi
 * @date 2025-02-12
 */
public interface IPileMachineInfoService {
    /**
     * 查询施工桩机信息
     * 
     * @param id 施工桩机信息主键
     * @return 施工桩机信息
     */
    PileMachineInfo selectPileMachineInfoById(Long id);

    PileMachineInfo selectPileMachineInfoByByteId(String byteId);

    /**
     * 查询施工桩机信息列表
     * 
     * @param pileMachineInfo 施工桩机信息
     * @return 施工桩机信息集合
     */
    List<PileMachineInfo> selectPileMachineInfoList(PileMachineInfo pileMachineInfo);

    /**
     * 新增施工桩机信息
     * 
     * @param pileMachineInfo 施工桩机信息
     * @return 结果
     */
    int insertPileMachineInfo(PileMachineInfo pileMachineInfo);

    /**
     * 修改施工桩机信息
     * 
     * @param pileMachineInfo 施工桩机信息
     * @return 结果
     */
    int updatePileMachineInfo(PileMachineInfo pileMachineInfo);

    int updatePileMachineInfoWidthPwd(PileMachineInfo pileMachineInfo);

    /**
     * 批量删除施工桩机信息
     * 
     * @param ids 需要删除的施工桩机信息主键集合
     * @return 结果
     */
    int deletePileMachineInfoByIds(Long[] ids);

    /**
     * 删除施工桩机信息信息
     * 
     * @param id 施工桩机信息主键
     * @return 结果
     */
    int deletePileMachineInfoById(Long id);

    List<PileMachineInfo> qryUnitMachine(Long consUnitId);

    List<ConstUnitNode> qryMachineAssignedUnit(String machineId);

    List<ConsPileHoleInfoVO> machineUnitPileHole(MachineBiz machineBiz);

    public HashMap<String, Integer> cntMachineOnOffline();

    public List<PileMachineInfo> selectMachineByConsUnitId(Long consUnitId);
}
